@@ -6,6 +6,7 @@ from urllib import parse
 class Router:
 
     param_macher = re.compile(r"\(\?P<([^>]+)>[^)]*\)")
+    repr_pattern = "{0: <6} {1: <40} -> {2}"
 
     def __init__(self):
         self.__idx__ = defaultdict(list)
@@ -49,7 +50,10 @@ class Router:
         while len(segments):
             index = '/'.join(segments)
             if index in self.__idx__:
-                return self.match_rule(method, path, self.__idx__[index])
+                handler, params = self.match_rule(method, path,
+                                                  self.__idx__[index])
+                if handler:
+                    return handler, params
             segments.pop()
         return None, None
 
@@ -81,7 +85,7 @@ class Router:
         return path
 
     def __repr__(self):
-        return "\n".join(["%s %s -> %s" %
-                          (method, pattern.pattern, handler.__qualname__)
+        return "\n".join([self.repr_pattern.format(method, pattern.pattern,
+                                                   handler.__qualname__)
                           for rules in self.__idx__.values()
                           for (method, pattern, handler) in rules])
